#!/bin/bash
source "${AGENT_PATH}/_common.sh"
_check_required_env_vars "CONTAINER_NAME" "LOCAL_DATA_FOLDER" "HOST_PORT" "IMAGE_REGISTRY" "IMAGE_REPO" "IMAGE_TAG"

# START SCRIPT
# The start script is required for all templates.
# It is used to start the service on the server.
# It is called with the path to the server specific env file as an argument.


[ -d "${LOCAL_DATA_FOLDER}" ] || _die "Local data folder ${LOCAL_DATA_FOLDER} does not exist."

DOCKER_RUN_CMD="docker run -d \
                --restart unless-stopped \
                --name ${CONTAINER_NAME} \
                -p ${HOST_PORT}:80 \
                -v ${LOCAL_DATA_FOLDER}:/usr/share/nginx/html:ro \
                ${IMAGE_REGISTRY}/${IMAGE_REPO}:${IMAGE_TAG}"


if ! create_and_start_container "$DOCKER_RUN_CMD" "$CONTAINER_NAME"; then
    _die "Failed to start container ${CONTAINER_NAME}"
fi

# Check if the container is running
if ! _is_container_running "$CONTAINER_NAME"; then
    _die "Container ${CONTAINER_NAME} is not running"
fi

echo "Container ${CONTAINER_NAME} started"
